@@ -12,6 +12,8 @@ from base64 import b64decode
 from wtforms.fields import TextField
 from flask.ext.admin.form import RenderTemplateWidget
 
+_unset_value = object()
+
 
 class RemoteFileModelMixin:
     def get_path(self):
@@ -115,6 +117,10 @@ class RemoteFileField(TextField):
         if valuelist:
             self.data = valuelist[0]
 
+    def process_data(self, value):
+        print value
+        TextField.__init__(self, value)
+
     def populate_obj(self, obj, name):
         if getattr(obj, name) is None:
             newfile = getattr(obj.__class__, name).mapper.class_()
@@ -145,7 +151,7 @@ class PictureField(TextField):
 
     def process_formdata(self, valuelist):
         if self.data:
-            self.data.path = valuelist[0]
+            self.data.set_path(valuelist[0])
 
 
 class FileAdmin(fileadmin.FileAdmin):
